@@ -7,7 +7,10 @@ import docker
 import traceback
 import logging
 import signal
-from distutils.dir_util import copy_tree
+
+from distutils.dir_util import copy_tree, remove_tree
+from distutils.dir_util import mkpath
+from distutils.file_util import write_file
 from future.moves import subprocess
 
 logger=logging.getLogger('mldock')
@@ -101,6 +104,9 @@ def deploy_model(working_dir, docker_tag, image_name, entrypoint, cmd, port=8080
         logger.error(exception)
 
 def pretty_build_logs(line: dict):
+
+    if line is None:
+        return None
     error = line.get('error', None)
     errorDetail = line.get('errorDetail', None)
     if error is not None:
@@ -119,7 +125,8 @@ def docker_build(
     module_path: str,
     target_dir_name: str,
     requirements_file_path: str,
-    no_cache: bool
+    no_cache: bool,
+    client = None
 ):
     """Runs the build executable from script path, passing a set of arguments in a command line subprocess.
 
@@ -132,14 +139,15 @@ def docker_build(
         target_dir_name (str):
         requirements_file_path (str):
     """
-    logger.info("\nStarting build...\n")
+
+    # if client is None:
+        # client = docker.from_env()
+    client = docker.APIClient(base_url=os.environ.get('DOCKER_HOST','tcp://127.0.0.1:1234'))
+
     try:
-        cli = docker.APIClient(
-            base_url=os.environ.get('DOCKER_HOST', 'tcp://127.0.0.1:2375')
-        )
         short_log = []
 
-        logs = cli.build(
+        logs = client.build(
             tag=image_name,
             path='.',
             dockerfile=os.path.join(dockerfile_path, 'Dockerfile'),
@@ -156,16 +164,20 @@ def docker_build(
 
         for line in logs:
             pretty_build_logs(line=line)
-        logger.info("\nBuild Complete! ヽ(´▽`)/")
     except (KeyboardInterrupt, SystemExit) as exception:
         logger.error(exception)
-        # container.kill()
     except (docker.errors.APIError, docker.errors.ContainerError, docker.errors.ImageNotFound) as exception:
         logger.info(exception)
         logger.error(exception)
     except Exception as exception:
         logger.error(exception)
 
+def _write_file(filepath, parents=True):
+    """write a file"""
+    if parents == True:
+        mkpath(str(Path(filepath).parents[0].absolute()))
+    write_file(str(Path(filepath).absolute()), '')
+
 def _rename_file(base_path, current_filename, new_filename):
     """renames filename for a given base_path, saving the file in the same base_path
 
@@ -186,7 +198,7 @@ def _create_empty_file(base_path, filename):
     """
     Path(base_path, filename).touch(exist_ok=True)
 
-def _copy_boilerplate_to_dst(src: str, dst: str):
+def _copy_boilerplate_to_dst(src: str, dst: str, remove_first=False):
     """[summary]
 
     Args:
@@ -195,52 +207,10 @@ def _copy_boilerplate_to_dst(src: str, dst: str):
     """
     source_path = str(Path(src).absolute())
     destination_path = str(Path(dst).absolute())
-    copy_tree(source_path, destination_path)
-
-
-def run_predict(script_path: str, host: str, payload: str, content_type: str):
-    """Runs the predict shell script and passes the arguments as expected by the script.
-
-    Args:
-        script_path (str): relative path to script when run on root
-        host (str): http/https host uri
-        payload (str): relative path to payload file when run on root
-        content_type (str): content type for request
-    """
-    logger.info("\nRunning Prediction...\n") 
-
-    try:
-        if content_type == 'application/json':
-            result = subprocess.run([
-                    script_path,
-                    host,
-                    payload,
-                    content_type
-                ],
-                stdout=subprocess.PIPE
-            )
-            decoded_stdout = json.loads(result.stdout.decode())
-            pretty_output = json.dumps(decoded_stdout, indent=4, separators=(',', ': '), sort_keys=True)
-        elif content_type == 'text/csv':
-            result = subprocess.run([
-                    script_path,
-                    host,
-                    payload,
-                    content_type
-                ],
-                stdout=subprocess.PIPE
-            )
-            pretty_output = result.stdout.decode()
-        else:
-            raise Exception('Only Supports application/json or text/csv')
-
-        logger.info(pretty_output)
-        logger.info("\nPrediction Complete! ヽ(´▽`)/")
-        return pretty_output
-
-    except subprocess.CalledProcessError as e:
-        logger.debug(e.output)
-        raise
-    except Exception as e:
-        logger.error("{}".format(e))
-        sys.exit(-1)
+    if remove_first == True:
+        try:
+            logger.debug("removing first")
+            remove_tree(destination_path)
+        except FileNotFoundError as exception:
+            logger.debug("No file found. Assuming already deleted.")
+    response = copy_tree(source_path, destination_path)
