@@ -28,10 +28,6 @@ def generic_init(dir, helper_library_path, mldock_config, testing_framework, ser
         dir,
         'service'
     )
-    container_directory = os.path.join(
-        service_directory,
-        'container'
-    )
 
     logger.info("getting template")
     template_dir = mldock_config.get("template_dir", None)
@@ -54,12 +50,15 @@ def generic_init(dir, helper_library_path, mldock_config, testing_framework, ser
 
     test_path = os.path.join(mldock_module_path, 'local_test', 'test_dir')
 
-    # generic copy
-    if container_only:
-        logger.info("Setting up container in workspace")
-        _copy_boilerplate_to_dst(os.path.join(template_dir,'src/container/'), container_directory)
-    else:
-        logger.info("Creating new workspace")
+    logger.info("Setting up workspace")   
+    logger.debug("Adding container")
+    _copy_boilerplate_to_dst(
+        os.path.join(template_dir,'src/container'),
+        mldock_module_path,
+        remove_first=True
+    )
+    if container_only == False:
+        logger.debug("Adding src scripts")
         _copy_boilerplate_to_dst(os.path.join(template_dir,'src/'), src_directory)
 
     if testing_framework == 'pytest':
@@ -101,12 +100,6 @@ def sagemaker_init(dir, helper_library_path, mldock_config, no_prompt, testing_f
         'service'
     )
 
-
-    container_directory = os.path.join(
-        service_directory,
-        'container'
-    )
-
     logger.info("getting template")
     template_dir = mldock_config.get("template_dir", None)
 
@@ -127,12 +120,15 @@ def sagemaker_init(dir, helper_library_path, mldock_config, no_prompt, testing_f
 
     test_path = os.path.join(mldock_module_path, 'local_test', 'test_dir')
 
-    # generic copy
-    if container_only:
-        logger.info("Setting up container in workspace")
-        _copy_boilerplate_to_dst(os.path.join(template_dir,'src/container/'), container_directory)
-    else:
-        logger.info("Creating new workspace")
+    logger.info("Setting up workspace")   
+    logger.debug("Adding container")
+    _copy_boilerplate_to_dst(
+        os.path.join(template_dir,'src/container'),
+        mldock_module_path,
+        remove_first=True
+    )
+    if container_only == False:
+        logger.debug("Adding src scripts")
         _copy_boilerplate_to_dst(os.path.join(template_dir,'src/'), src_directory)
 
     if testing_framework == 'pytest':
