@@ -21,7 +21,7 @@ logger=logging.getLogger('mldock')
 @click.group()
 def container():
     """
-    Commands for local operations: train and deploy
+    Manage and create new container projects. Create new templates from mldock container projects.
     """
     pass
 
@@ -58,8 +58,9 @@ def create_template(obj, name, dir, out):
 @click.option('--testing_framework', default=None, help='(Optional) Pytest framework. This creates a few health-check tests')
 @click.option('--service', default=None, help='(Optional) Docker Compose. This seeds a service config.')
 @click.option('--no-prompt', is_flag=True, help='Do not prompt user, instead use the mldock config to initialize the container.')
+@click.option('--container-only', is_flag=True, help='Only inject new container assets.')
 @click.pass_obj
-def init(obj, dir, testing_framework, service, no_prompt):
+def init(obj, dir, testing_framework, service, no_prompt, container_only):
     """
     Command to initialize container configs required by sagemaker-training.
     """
@@ -134,7 +135,8 @@ def init(obj, dir, testing_framework, service, no_prompt):
                 mldock_config=mldock_config,
                 no_prompt=no_prompt,
                 testing_framework=testing_framework,
-                service=service
+                service=service,
+                container_only=container_only
             )
         elif platform == "sagemakerv2":
             # pass down any information like hyperparameters, etc
@@ -144,7 +146,8 @@ def init(obj, dir, testing_framework, service, no_prompt):
                 mldock_config=mldock_config,
                 no_prompt=no_prompt,
                 testing_framework=testing_framework,
-                service=service
+                service=service,
+                container_only=container_only
             )
         elif platform == "generic":
             # pass down any information like hyperparameters, etc
@@ -153,7 +156,8 @@ def init(obj, dir, testing_framework, service, no_prompt):
                 helper_library_path=helper_library_path,
                 mldock_config=mldock_config,
                 testing_framework=testing_framework,
-                service=service
+                service=service,
+                container_only=container_only
             )
         else:
             raise Exception("Platform not found. Please supply available platform template.")
